@@ -54,12 +54,7 @@ class GetExcludePatternsForDir(unittest.TestCase):
   def tearDown(self):  # pylint: disable=g-missing-super-call
     shutil.rmtree(self.test_tmpdir)
 
-  def _make_test_dir(self, name):
-    fullpath = os.path.normpath(os.path.join(self.test_tmpdir, name))
-    os.makedirs(fullpath)
-    return fullpath
-
-  def test_get_exclude_file_patterns(self):
+  def test_get_exclude_file_patterns_from_yapfignore(self):
     local_ignore_file = os.path.join(self.test_tmpdir, '.yapfignore')
     ignore_patterns = ['temp/**/*.py', 'temp2/*.py']
     with open(local_ignore_file, 'w') as f:
@@ -69,6 +64,83 @@ class GetExcludePatternsForDir(unittest.TestCase):
         sorted(file_resources.GetExcludePatternsForDir(self.test_tmpdir)),
         sorted(ignore_patterns))
 
+  def test_get_exclude_file_patterns_from_yapfignore_with_wrong_syntax(self):
+    local_ignore_file = os.path.join(self.test_tmpdir, '.yapfignore')
+    ignore_patterns = ['temp/**/*.py', './wrong/syntax/*.py']
+    with open(local_ignore_file, 'w') as f:
+      f.writelines('\n'.join(ignore_patterns))
+
+    with self.assertRaises(errors.YapfError):
+      file_resources.GetExcludePatternsForDir(self.test_tmpdir)
+
+  def test_get_exclude_file_patterns_from_pyproject(self):
+    try:
+      import tomli
+    except ImportError:
+      return
+    local_ignore_file = os.path.join(self.test_tmpdir, 'pyproject.toml')
+    ignore_patterns = ['temp/**/*.py', 'temp2/*.py']
+    with open(local_ignore_file, 'w') as f:
+      f.write('[tool.yapfignore]\n')
+      f.write('ignore_patterns=[')
+      f.writelines('\n,'.join(['"{}"'.format(p) for p in ignore_patterns]))
+      f.write(']')
+
+    self.assertEqual(
+        sorted(file_resources.GetExcludePatternsForDir(self.test_tmpdir)),
+        sorted(ignore_patterns))
+
+  @unittest.skipUnless(py3compat.PY36, 'Requires Python 3.6')
+  def test_get_exclude_file_patterns_from_pyproject_with_wrong_syntax(self):
+    try:
+      import tomli
+    except ImportError:
+      return
+    local_ignore_file = os.path.join(self.test_tmpdir, 'pyproject.toml')
+    ignore_patterns = ['temp/**/*.py', './wrong/syntax/*.py']
+    with open(local_ignore_file, 'w') as f:
+      f.write('[tool.yapfignore]\n')
+      f.write('ignore_patterns=[')
+      f.writelines('\n,'.join(['"{}"'.format(p) for p in ignore_patterns]))
+      f.write(']')
+
+    with self.assertRaises(errors.YapfError):
+      file_resources.GetExcludePatternsForDir(self.test_tmpdir)
+
+  def test_get_exclude_file_patterns_from_pyproject_no_ignore_section(self):
+    try:
+      import tomli
+    except ImportError:
+      return
+    local_ignore_file = os.path.join(self.test_tmpdir, 'pyproject.toml')
+    ignore_patterns = []
+    open(local_ignore_file, 'w').close()
+
+    self.assertEqual(
+        sorted(file_resources.GetExcludePatternsForDir(self.test_tmpdir)),
+        sorted(ignore_patterns))
+
+  def test_get_exclude_file_patterns_from_pyproject_ignore_section_empty(self):
+    try:
+      import tomli
+    except ImportError:
+      return
+    local_ignore_file = os.path.join(self.test_tmpdir, 'pyproject.toml')
+    ignore_patterns = []
+    with open(local_ignore_file, 'w') as f:
+      f.write('[tool.yapfignore]\n')
+
+    self.assertEqual(
+        sorted(file_resources.GetExcludePatternsForDir(self.test_tmpdir)),
+        sorted(ignore_patterns))
+
+  def test_get_exclude_file_patterns_with_no_config_files(self):
+    ignore_patterns = []
+
+    self.assertEqual(
+        sorted(file_resources.GetExcludePatternsForDir(self.test_tmpdir)),
+        sorted(ignore_patterns))
+
 
 class GetDefaultStyleForDirTest(unittest.TestCase):
 
@@ -117,6 +189,26 @@ class GetDefaultStyleForDirTest(unittest.TestCase):
     self.assertEqual(setup_config,
                      file_resources.GetDefaultStyleForDir(test_dir))
 
+  def test_pyproject_toml(self):
+    # An empty pyproject.toml file should not be used
+    try:
+      import tomli
+    except ImportError:
+      return
+
+    pyproject_toml = os.path.join(self.test_tmpdir, 'pyproject.toml')
+    open(pyproject_toml, 'w').close()
+
+    test_dir = os.path.join(self.test_tmpdir, 'dir1')
+    style_name = file_resources.GetDefaultStyleForDir(test_dir)
+    self.assertEqual(style_name, 'pep8')
+
+    # One with a '[tool.yapf]' section should be used
+    with open(pyproject_toml, 'w') as f:
+      f.write('[tool.yapf]\n')
+    self.assertEqual(pyproject_toml,
+                     file_resources.GetDefaultStyleForDir(test_dir))
+
   def test_local_style_at_root(self):
     # Test behavior of files located on the root, and under root.
     rootdir = os.path.abspath(os.path.sep)
@@ -152,8 +244,8 @@ class GetCommandLineFilesTest(unittest.TestCase):
     self.old_dir = os.getcwd()
 
   def tearDown(self):  # pylint: disable=g-missing-super-call
-    shutil.rmtree(self.test_tmpdir)
     os.chdir(self.old_dir)
+    shutil.rmtree(self.test_tmpdir)
 
   def _make_test_dir(self, name):
     fullpath = os.path.normpath(os.path.join(self.test_tmpdir, name))
@@ -258,7 +350,7 @@ class GetCommandLineFilesTest(unittest.TestCase):
     child of the current directory which has been specified in a relative
     manner.
 
-    At its core, the bug has to do with overzelous stripping of "./foo" so that
+    At its core, the bug has to do with overzealous stripping of "./foo" so that
     it removes too much from "./.foo" .
     """
     tdir1 = self._make_test_dir('.test1')
@@ -313,7 +405,8 @@ class GetCommandLineFilesTest(unittest.TestCase):
                                                'test2/testinner/',
                                            ]))
 
-    self.assertEqual(found, ['test3/foo/bar/bas/xxx/testfile3.py'])
+    self.assertEqual(
+        found, ['test3/foo/bar/bas/xxx/testfile3.py'.replace("/", os.path.sep)])
 
     found = sorted(
         file_resources.GetCommandLineFiles(['.'],
@@ -323,7 +416,8 @@ class GetCommandLineFilesTest(unittest.TestCase):
                                                'test3',
                                            ]))
 
-    self.assertEqual(found, ['./test2/testinner/testfile2.py'])
+    self.assertEqual(
+        found, ['./test2/testinner/testfile2.py'.replace("/", os.path.sep)])
 
   def test_find_with_excluded_current_dir(self):
     with self.assertRaises(errors.YapfError):
@@ -386,7 +480,7 @@ class IsIgnoredTest(unittest.TestCase):
 
   def test_trailing_slash(self):
     self.assertTrue(file_resources.IsIgnored('z', ['z']))
-    self.assertTrue(file_resources.IsIgnored('z', ['z/']))
+    self.assertTrue(file_resources.IsIgnored('z', ['z' + os.path.sep]))
 
 
 class BufferedByteStream(object):
@@ -431,7 +525,7 @@ class WriteReformattedCodeTest(unittest.TestCase):
     self.assertEqual(stream.getvalue(), s)
 
   def test_write_encoded_to_stdout(self):
-    s = '\ufeff# -*- coding: utf-8 -*-\nresult = "passed"\n'  # pylint: disable=anomalous-unicode-escape-in-string
+    s = '\ufeff# -*- coding: utf-8 -*-\nresult = "passed"\n'  # pylint: disable=anomalous-unicode-escape-in-string # noqa
     stream = BufferedByteStream() if py3compat.PY3 else py3compat.StringIO()
     with utils.stdout_redirector(stream):
       file_resources.WriteReformattedCode(
@@ -466,6 +560,26 @@ class LineEndingTest(unittest.TestCase):
     actual = file_resources.LineEnding(lines)
     self.assertEqual(actual, '\n')
 
+  def test_line_ending_empty(self):
+    lines = []
+    actual = file_resources.LineEnding(lines)
+    self.assertEqual(actual, '\n')
+
+  def test_line_ending_no_newline(self):
+    lines = ['spam']
+    actual = file_resources.LineEnding(lines)
+    self.assertEqual(actual, '\n')
+
+  def test_line_ending_tie(self):
+    lines = [
+        'spam\n',
+        'spam\n',
+        'spam\r\n',
+        'spam\r\n',
+    ]
+    actual = file_resources.LineEnding(lines)
+    self.assertEqual(actual, '\n')
+
 
 if __name__ == '__main__':
   unittest.main()
